[![Documentation Status](https://readthedocs.org/projects/psiexperiment/badge/?version=latest)](https://psiexperiment.readthedocs.io/en/latest/?badge=latest)

See our documentation on [readthedocs.org](https://psiexperiment.readthedocs.io).
